netapp_ontap.models.security_saml_sp_certificate API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved.

# Module `netapp_ontap.models.security_saml_sp_certificate`

Copyright © 2020 NetApp Inc. All rights reserved.

## Classes

`class SecuritySamlSpCertificateSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the SecuritySamlSpCertificate object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `ca GET POST`

    Server certificate issuing certificate authority (CA). This cannot be used with the server certificate common name.

  `common_name GET POST`

    Server certificate common name. This cannot be used with the certificate authority (CA) or serial_number.

    Example: cluster1

  `serial_number GET POST`

    Server certificate serial number. This cannot be used with the server certificate common name.

    Example: 1506B24A94F566BA